@@ -424,7 +424,7 @@ def Reports(paths,bodypart,fields=None,filter=0.3,fps = 30):
 
     import numpy as np
     import pandas as pd
-    import pyrat as rat
+    import pyratlib as rat
 
     relatorio = pd.DataFrame(columns=['file','time','dist', 'speed'])
   
